#ifndef SYSTEM_DEFINITION_H
#define SYSTEM_DEFINITION_H

/*!
  \file
  \brief isɂẴVXe`

  \author Satofumi KAMIMURA

  $Id$
*/


// ftHgݒ
enum {
  DefaultPracticeNum = 5,
};


// VXeݒ
enum {
  GameSchedulerId,
};

// Q[ݒ
enum {
#if 1
  KaminokuPlaying = 4500,
  ShimonokuPlaying = 3000,
  YomibitoPlaying = 1000,
#else
  KaminokuPlaying = 45,
  ShimonokuPlaying = 30,
  YomibitoPlaying = 10,
#endif
  TotalPlaying = KaminokuPlaying + ShimonokuPlaying,
};

// Web ANZX̃^CAEg
enum {
  WebAccessTimeout = 3000,
};

// ʂ̑ҋ@
enum {
  PrologueMsec = 5100,          //!< v[OԂ̑ҋ@ [msec]
};

// y̍Đ܂
enum {
  PlayFadeIn = 1000,
  StopFadeOut = 200,
};

#endif /* !SYSTEM_DEFINITION_H */
